# Flask Boilerplate Creator
Create boilerplate for flask web application

Install using pip

```cmd
> pip install Flask-Boilerplate-Creator
```

run the Flask-Boilerplate-Creator

```cmd
> python -m fbc
```

After running above command it will ask for other modules to be installed, if not leave it blank

```
Select modules to install
[0] flask-sqlalchemy
[1] flask-migrate
[2] flask-admin
[3] flask-wtf
[4] flask-session
Enter module index numbers separated by comma to add:
```

Enter pip command if default command is not working, in some os value for it may be `python3 -m pip install`

```
Enter pip command (default is 'python -m pip install'):
```

All ok, it will install the module now
After installing all modules it will create files and folders on your system
This operation will remove any file content or delete folder if exists

```
Installing modules: flask
using command python -m pip install
*Installing flask

##:- pip install output will be here

*Structure created successfully.
If you get error like module not found, run `python -m pip install -r requirements.txt` command.
```

Done - structure is created.
